@@ -1,5 +1,26 @@
+introotpn <- function(p) {
+    ## Find integer root of x^2-x-2*p=0
+    n <- 0.5*(1+sqrt(1+8*p))
+    if (floor(n)!=n) n <- NA
+    return(n)
+}
+rho2sigma <- function(rho) {
+    if (length(rho)==1) return(diag(2)*(1-rho)+rho)
+    p <- introotpn(length(rho))
+    if (is.na(p)) stop("Unexpected length of correlation coefficients (p=n*(n-1)/2).")
+    sigma <- diag(nrow=p)
+    offdiag(sigma,type=2) <- rho
+    offdiag(sigma,type=3) <- offdiag(t(sigma),type=3)
+    return(sigma)
+}
+
 ##' @export
-rmvn <- function(n,mu=rep(0,ncol(sigma)),sigma=diag(nrow=length(mu))*.5+.5,...) {
+rmvn <- function(n,mu,sigma,rho,...) {
+    if (!missing(rho)) sigma <- rho2sigma(rho)
+    if (!missing(mu) && missing(sigma)) sigma <- diag(nrow=length(mu))
+    if (missing(sigma)) sigma <- matrix(1)
+    if (is.vector(sigma)) sigma <- diag(sigma,ncol=length(sigma))
+    if (missing(mu)) mu <- rep(0,ncol(sigma))    
     PP <- with(svd(sigma), v%*%diag(sqrt(d),ncol=length(d))%*%t(u))
     res <- matrix(rnorm(ncol(sigma)*n),ncol=ncol(sigma))%*%PP
     if (NROW(mu)==nrow(res) && NCOL(mu)==ncol(res)) return(res+mu)
@@ -7,7 +28,13 @@ rmvn <- function(n,mu=rep(0,ncol(sigma)),sigma=diag(nrow=length(mu))*.5+.5,...)
 }
 
 ##' @export
-dmvn <- function(x,mu,sigma,log=FALSE,nan.zero=TRUE,norm=TRUE,...) {
+dmvn <- function(x,mu,sigma,rho,log=FALSE,nan.zero=TRUE,norm=TRUE,...) {
+    if (!missing(rho)) sigma <- rho2sigma(rho)
+    if (!missing(mu) && missing(sigma)) sigma <- diag(nrow=length(mu))
+    if (missing(sigma)) sigma <- matrix(1)
+    if (is.vector(sigma)) sigma <- diag(sigma,ncol=length(sigma))
+    if (missing(mu)) mu <- rep(0,ncol(sigma))
+    
     if (length(sigma)==1) {
         k <- 1
         isigma <- structure(cbind(1/sigma),det=as.vector(sigma))
@@ -82,6 +109,7 @@ normal_objective.lvm <- function(x,p,data,weights=NULL,data2=NULL,indiv=FALSE,..
     }
 
     l <- mets::loglikMVN(yl,yu,status,mu,S,thres)
+    
     if (!is.null(weights)) {
         ##if (is.matrix(weights)) weights <- weights[,1]
         l <- l*weights
@@ -94,17 +122,18 @@ normal_objective.lvm <- function(x,p,data,weights=NULL,data2=NULL,indiv=FALSE,..
     return(-sum(l))
 }
 
+
 normal_logLik.lvm <- function(object,p,data,data2=NULL,...) {
     res <- -normal_objective.lvm(x=object,p=p,data=data,data2=data2,...)
     return(res)
 }
 
-normal_gradient.lvm <- function(x,p,data,data2=NULL,indiv=FALSE,...) {
+normal_gradient.lvm <- function(x,p,data,weights=NULL,data2=NULL,indiv=FALSE,...) {
     if (!exists(".Random.seed", envir = .GlobalEnv, inherits = FALSE)) runif(1)
     save.seed <- get(".Random.seed", envir = .GlobalEnv)
     on.exit(assign(".Random.seed", save.seed, envir = .GlobalEnv))
     if (!requireNamespace("mets",quietly=TRUE)) stop("'mets' package required")
-    if  (is.null(ordinal(x))) {
+    if  (is.null(ordinal(x)) && is.null(data2) && is.null(weights)) {
         D <- deriv.lvm(x,p=p)
         M <- moments(x,p)
         Y <- as.matrix(data[,manifest(x)])
@@ -114,9 +143,9 @@ normal_gradient.lvm <- function(x,p,data,data2=NULL,indiv=FALSE,...) {
         return(ss)
     }
     if (indiv) {
-        return(numDeriv::jacobian(function(p0) normal_objective.lvm(x,p=p0,data=data,data2=data2,indiv=TRUE,...),p,method=lava.options()$Dmethod))
+        return(numDeriv::jacobian(function(p0) normal_objective.lvm(x,p=p0,data=data,weights=weights,data2=data2,indiv=TRUE,...),p,method=lava.options()$Dmethod))
     }
-    numDeriv::grad(function(p0) normal_objective.lvm(x,p=p0,data=data,data2=data2,...),p,method=lava.options()$Dmethod)
+    numDeriv::grad(function(p0) normal_objective.lvm(x,p=p0,data=data,weights=weights,data2=data2,...),p,method=lava.options()$Dmethod)
 }
 
 normal_hessian.lvm <- function(x,p,outer=FALSE,data2=NULL,...) {
