@@ -5,7 +5,7 @@ function(x,...) UseMethod("score")
 ###{{{ score.lvm
 
 ##' @export
-score.lvm <- function(x, data, p, model="gaussian", S, n, mu=NULL, weight=NULL, weight2=NULL, debug=FALSE, reindex=FALSE, mean=TRUE, constrain=TRUE, indiv=TRUE,...) {
+score.lvm <- function(x, data, p, model="gaussian", S, n, mu=NULL, weights=NULL, data2=NULL, debug=FALSE, reindex=FALSE, mean=TRUE, constrain=TRUE, indiv=TRUE,...) {
 
   cl <- match.call()
   lname <- paste0(model,"_score.lvm")
@@ -62,7 +62,7 @@ score.lvm <- function(x, data, p, model="gaussian", S, n, mu=NULL, weight=NULL,
         for (i in seq_along(myfix$var)) {
           index(x0)$A[cbind(myfix$row[[i]],myfix$col[[i]])] <- data[ii,myfix$var[[i]]]
         }
-      return(scoreFun(x0,data=data[ii,], p=with(pp,c(meanpar,p,p2)),weight=weight[ii,,drop=FALSE],weight2=weight2[ii,,drop=FALSE],model=model,debug=debug,indiv=indiv,...))
+      return(scoreFun(x0,data=data[ii,], p=with(pp,c(meanpar,p,p2)),weights=weights[ii,,drop=FALSE],data2=data2[ii,,drop=FALSE],model=model,debug=debug,indiv=indiv,...))
     }
     score <- t(sapply(seq_len(nrow(data)),myfun))
     if (!indiv) {
@@ -88,13 +88,13 @@ score.lvm <- function(x, data, p, model="gaussian", S, n, mu=NULL, weight=NULL,
 ##' @export
 score.lvm.missing <- function(x,
                           p=pars(x), estimator=x$estimator,
-                              weight=Weight(x$estimate),
+                              weights=Weights(x$estimate),
                               indiv=FALSE,
                               list=FALSE,
                               ...) {
     dots <- list(...)
     dots$combine <- FALSE
-    S <- do.call("score",c(list(x=x$estimate$model0,p=p, model=estimator, weight=weight, indiv=indiv),dots))
+    S <- do.call("score",c(list(x=x$estimate$model0,p=p, model=estimator, weights=weights, indiv=indiv),dots))
     if (indiv & !list) {
         S0 <- matrix(ncol=length(p),nrow=length(x$order))
         rownames(S0) <- seq_len(nrow(S0))
@@ -118,8 +118,8 @@ score.lvm.missing <- function(x,
 ###{{{ score.multigroupfit
 
 ##' @export
-score.multigroupfit <- function(x,p=pars(x), weight=Weight(x), estimator=x$estimator, ...) {
-  score(x$model0, p=p, weight=weight, model=estimator,...)
+score.multigroupfit <- function(x,p=pars(x), weights=Weights(x), estimator=x$estimator, ...) {
+  score(x$model0, p=p, weights=weights, model=estimator,...)
 }
 
 ###}}} score.multigroupfit
@@ -127,13 +127,13 @@ score.multigroupfit <- function(x,p=pars(x), weight=Weight(x), estimator=x$estim
 ###{{{ score.multigroup
 
 ##' @export
-score.multigroup <- function(x,data=x$data,weight=NULL,weight2=NULL,p,indiv=combine,combine=FALSE,...) {
+score.multigroup <- function(x,data=x$data,weights=NULL,data2=NULL,p,indiv=combine,combine=FALSE,...) {
   rm <- procrandomslope(x)
   pp <- with(rm, modelPar(model,p)$p)
   parord <- modelPar(rm$model,seq_len(with(rm$model,npar+npar.mean)))$p
   S <- list()
   for (i in seq_len(x$ngroup)) {
-    S0 <- rbind(score(x$lvm[[i]],p=pp[[i]],data=data[[i]],weight=weight[[i]],weight2=weight2[[i]],indiv=indiv,...))
+    S0 <- rbind(score(x$lvm[[i]],p=pp[[i]],data=data[[i]],weights=weights[[i]],data2=data2[[i]],indiv=indiv,...))
     S1 <- matrix(ncol=length(p),nrow=nrow(S0))
     S1[,parord[[i]]] <- S0
     S <- c(S, list(S1))
@@ -155,8 +155,8 @@ score.multigroup <- function(x,data=x$data,weight=NULL,weight2=NULL,p,indiv=comb
 ###{{{ score.lvmfit
 
 ##' @export
-score.lvmfit <- function(x, data=model.frame(x), p=pars(x), model=x$estimator, weight=Weight(x), weight2=x$data$weight2, ...) {
-  score(x$model0,data=data,p=p,model=model,weight=weight,weight2=weight2,...)
+score.lvmfit <- function(x, data=model.frame(x), p=pars(x), model=x$estimator, weights=Weights(x), data2=x$data$data2, ...) {
+  score(x$model0,data=data,p=p,model=model,weights=weights,data2=data2,...)
 }
 
 ###}}} score.lvmfit
