@@ -1,3 +1,9 @@
+char2num <- function(x,...) {
+    idx <- grep("^[-]*[0-9\\.]+",x,perl=TRUE,invert=TRUE)
+    if (length(idx)>0) x[idx] <- NA
+    as.numeric(x)
+}
+
 ###{{{ substArg
 
 substArg <- function(x,env,...) {
@@ -120,7 +126,7 @@ izero <- function(i,n) { ## n-1 zeros and 1 at ith entry
 
 ###{{{ categorical2dummy
 
-categorical2dummy <- function(x,data,silent=TRUE,...) {
+categorical2dummy <- function(x,data,messages=0,...) {
   x0 <- x
   X <- intersect(index(x)$exogenous,colnames(data))
   catX <- c()
@@ -147,9 +153,9 @@ categorical2dummy <- function(x,data,silent=TRUE,...) {
       fix <- as.list(F$labels[i,])
       fixval <- F$values[i,]
       fix[which(!is.na(fixval))] <- fixval[na.omit(fixval)]
-      regression(x0,to=Y,from=mnames,silent=silent) <- fix[Y]
+      regression(x0,to=Y,from=mnames,messages=messages) <- fix[Y]
     } else {
-      x0 <- regression(x0,to=Y,from=mnames,silent=silent)
+      x0 <- regression(x0,to=Y,from=mnames,messages=messages)
     }
   }
   index(x0) <- reindex(x0,zeroones=TRUE,deriv=TRUE)
@@ -269,52 +275,6 @@ function(M, upper=TRUE) {
 
 ###}}}
 
-###{{{ Inverse/pseudo
-
-##' @export
-Inverse <- function(X,tol=lava.options()$itol,det=TRUE,names=!chol,chol=FALSE,symmetric=FALSE) {
-    n <- NROW(X)
-                                        # return(structure(solve(X),))
-    if (n==1L) {
-        res <- 1/X
-        if (det) attributes(res)$det <- X
-        if (chol) attributes(res)$chol <- X
-        return(res)
-    }
-    if (chol) {
-        L <- chol(X)
-        res <- chol2inv(L)
-        if (det) attributes(res)$det <- prod(diag(L)^2)
-        if (chol) attributes(res)$chol <- X        
-    } else {
-        if(symmetric){
-            decomp <- eigen(X, symmetric = TRUE)
-            D <- decomp$values
-            U <- decomp$vectors
-            V <- decomp$vectors
-        }else{
-            X.svd <- svd(X)
-            U <- X.svd$u
-            V <- X.svd$v
-            D <- X.svd$d
-        }
-        id0 <- numeric(n)
-        idx <- which(abs(D)>tol)
-        id0[idx] <- 1/D[idx]
-        res <- V%*%diag(id0,nrow=length(id0))%*%t(U)
-        
-        if (det) 
-            attributes(res)$det <- prod(D[D>tol])
-        attributes(res)$pseudo <- (length(idx)<n)
-        attributes(res)$minSV <- min(D)
-        
-    }
-    if (names && !is.null(colnames(X))) dimnames(res) <- list(colnames(X),colnames(X))
-    return(res)
-}
-
-###}}}
-
 ###{{{ naiveGrad
 
 naiveGrad <- function(f, x, h=1e-9) {
@@ -471,7 +431,7 @@ Decomp.specials <- function(x,pattern="[()]") {
   vars <- mysplit[1]
   res <- unlist(strsplit(vars,","))
   if (type=="s" | type=="seq") {
-    return(paste0(res[1],seq(as.numeric(res[2]))))
+    return(paste0(res[1],seq(char2num(res[2]))))
   }
   unlist(strsplit(vars,","))
 
